#
# spec file for package hmcfgusb
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2019 Andreas Vetter
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           hmcfgusb
Version:        0.103+git23.g7157286
Release:        bp155.1.6
Summary:        Hmland and utilities to use the HM-CFG-USB(2)
License:        MIT AND SUSE-Public-Domain
Group:          System/Monitoring
URL:            https://git.zerfleddert.de/cgi-bin/gitweb.cgi/hmcfgusb
Source:         %{name}-%{version}.tar.gz
Source1:        hmland.service
Source2:        sysconfig.hmland
BuildRequires:  libusb-1_0-devel
BuildRequires:  pkgconfig(systemd)
Requires:       logrotate
Requires(pre):  %fillup_prereq

%description
This package contains, amongst others, hmland an application, which emulates the
HomeMatic LAN configuration adapter-protocol to make it possible to use the
HM-CFG-USB in Fhem or as a lan configuration tool for the CCU or the
HomeMatic windows configuration software, also supporting devices using
AES-signing like KeyMatic.

%prep
%setup -q

%build
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_bindir}
install -m 755 flash-hmcfgusb  %{buildroot}%{_bindir}
install -m 755 flash-hmmoduart %{buildroot}%{_bindir}
install -m 755 flash-ota       %{buildroot}%{_bindir}
install -m 755 hmsniff         %{buildroot}%{_bindir}

mkdir -p %{buildroot}%{_sbindir}
install -m 755 hmland          %{buildroot}%{_sbindir}

install -d -m 755 %{buildroot}%{_sysconfdir}/logrotate.d
install -m 644 debian/hmland.logrotate  %{buildroot}%{_sysconfdir}/logrotate.d/hmland

mkdir -p %{buildroot}%{_fillupdir}
install -m 644 %{_sourcedir}/sysconfig.hmland %{buildroot}%{_fillupdir}/sysconfig.hmland
install -D -m 0644 %{_sourcedir}/hmland.service %{buildroot}/%{_unitdir}/hmland.service
ln -s service %{buildroot}%{_sbindir}/rchmland

%pre
%service_add_pre hmland.service

%post
%service_add_post hmland.service
%{fillup_only -ans hmland}

%preun
%service_del_preun hmland.service

%postun
%service_del_postun hmland.service

%files
%defattr (-,root,root,755)
%config /%{_sysconfdir}/logrotate.d/hmland
%{_bindir}/flash-hmcfgusb
%{_bindir}/flash-hmmoduart
%{_bindir}/flash-ota
%{_bindir}/hmsniff
%{_sbindir}/hmland
%{_sbindir}/rchmland
%{_fillupdir}/sysconfig.hmland
%{_unitdir}/hmland.service
%doc README.md debian/changelog
%license LICENSE

%changelog
* Thu Dec  8 2022 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- Update to HEAD (git 715728607ae77bebf3ac50fdbdb46639551995e4, 15 Sep 2020)
  * firmware: fix maximum size master
  * flash-ota: add support for directly flashing AsksinPP...
  * Suppress warnings about non-literal format strings
  * Allow the user to specify the compiler via environment...
  * Cleanup: Use := for assignment
  * Cleanup: Use size_t for len
  * Cleanup: Use correct format string
  * Add missing case in switch
  * Cleanup: Cast explicitly where integers of different...
  * Cleanup: Add missing 'void'
  * Cleanup: Improve const correctness
  * Add support for printing the transfer status
  * enable-hmmodiprf: add small script to enable a tty...
  * consistency in state names
  * hmuartlgw: add a bit of support for HmIP-RFUSB-TK
  * hmland.init: try hmland-location from Fhem-wiki, too
  * README: change clone-URL to https
  * hmuartlgw: Add timeout during module initialization
  * hmuartlgw: Add minimal support for DualCoPro-firmware
* Fri Oct 15 2021 Johannes Segitz <jsegitz@suse.com>
- Drop ProtectClock hardening, can cause issues if other device acceess is needed
* Wed Sep 22 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * hmland.service
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut through the -mini flavors.
* Mon Mar 18 2019 Andreas Vetter <vetter@physik.uni-wuerzburg.de>
- Repair URL and Source in spec
* Thu Jun 14 2018 vetter@physik.uni-wuerzburg.de
- Remove unnecessary brackets fron description
* Thu Apr  5 2018 vetter@physik.uni-wuerzburg.de
- Mark LICENSE as %%license
* Mon Mar 26 2018 vetter@physik.uni-wuerzburg.de
- rename changes file
* Thu Mar 22 2018 vetter@physik.uni-wuerzburg.de
- removed _service and used spec-clean
* Mon Mar 12 2018 vetter@physik.uni-wuerzburg.de
- kicked pre-systemd support (SLE11)
* Tue Feb 27 2018 vetter@physik.uni-wuerzburg.de
- clean up spec file
* Sun Feb 11 2018 vetter@physik.uni-wuerzburg.de
- upgrade to hmcfgusb (0.103-1) unstable; urgency=low
  * flash-ota: add support for HM-HMOD-UART and TSCUL
  * hmsniff: add support for HM-MOD-UART
  * flash-hmmoduart: firmware updating on HM-MOD-UART
  * flash-ota: various bug-fixes
- adapt to systemd for newer distros
* Wed Feb 24 2016 vetter@physik.uni-wuerzburg.de
- Initial Packaging
- hmcfgusb-0.102
